:orphan:

.. _glossary:

Glossary
========

.. glossary::

  WSGI
    Web Server Gateway Interface. It is a specification that describes how a
    web server communicates with web applications, and how web applications
    can be chained together to process one request.
    WSGI is a Python standard described in detail in
    `PEP 3333 <https://www.python.org/dev/peps/pep-3333/>`_.

  Virtualenv
    An isolated Python environment. Allows you to control which packages
    are used on a particular project by cloning your main Python. virtualenv
    was created by Ian Bicking.

  Zope
    `The Z Object Publishing Framework <http://zope.org>`_.  The granddaddy 
    of Python web frameworks.
